measuretools.apply_durated_complex_beam_spanner_to_measures
===========================================================

.. autofunction:: abjad.tools.measuretools.apply_durated_complex_beam_spanner_to_measures.apply_durated_complex_beam_spanner_to_measures
